package org.jboss.cache.config;

/**
 * An interface used to configure an eviction algorithm.  Replaces the deprecated {@link org.jboss.cache.config.EvictionPolicyConfig}.
 * <p/>
 * In it's most basic form, it is implemented by {@link org.jboss.cache.eviction.EvictionAlgorithmConfigBase}, but
 * more specific eviction policies may subclass {@link org.jboss.cache.eviction.EvictionAlgorithmConfigBase} or re-implement
 * this interface to provide access to more config variables.
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
public interface EvictionAlgorithmConfig extends CloneableConfigurationComponent
{
   /**
    * Gets the class name of the {@link org.jboss.cache.eviction.EvictionAlgorithm} implementation
    * this object will configure.
    *
    * @return fully qualified class name
    */
   String getEvictionAlgorithmClassName();

   /**
    * Validate the configuration. Will be called after any configuration
    * properties are set.
    *
    * @throws ConfigurationException if any values for the configuration
    *                                properties are invalid
    */
   void validate() throws ConfigurationException;

   /**
    * Resets the values to their defaults.
    */
   void reset();

   /**
    * @return a clone of the EvictionAlgorithmConfig.
    */
   EvictionAlgorithmConfig clone() throws CloneNotSupportedException;
}
