/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.cache.eviction;

import org.jboss.cache.config.ConfigurationException;

/**
 * Configuration for {@link FIFOAlgorithm}.
 * <p/>
 * Requires a "maxNodes" attribute otherwise a ConfigurationException is thrown.
 *
 * @author Manik Surtani
 * @since 3.0
 */
public class FIFOAlgorithmConfig extends EvictionAlgorithmConfigBase
{
   /**
    * The serialVersionUID
    */
   private static final long serialVersionUID = -7229715009546277313L;

   public FIFOAlgorithmConfig()
   {
      evictionAlgorithmClassName = FIFOAlgorithm.class.getName();
      // We require that maxNodes is set
      setMaxNodes(-1);
   }

   public FIFOAlgorithmConfig(int maxNodes)
   {
      evictionAlgorithmClassName = FIFOAlgorithm.class.getName();
      // We require that maxNodes is set
      setMaxNodes(maxNodes);
   }

   /**
    * Requires a positive maxNodes value or ConfigurationException
    * is thrown.
    */
   @Override
   public void validate() throws ConfigurationException
   {
      super.validate();
      if (getMaxNodes() < 0)
      {
         throw new ConfigurationException("maxNodes must be must be " +
               "configured to a value greater than or equal to 0");
      }
   }

   @Override
   public String toString()
   {
      StringBuilder ret = new StringBuilder();
      ret.append("FIFOAlgorithmConfig: maxNodes = ").append(getMaxNodes());
      return ret.toString();
   }

   @Override
   public boolean equals(Object obj)
   {
      return (obj instanceof FIFOAlgorithmConfig && super.equals(obj));
   }

   @Override
   public void reset()
   {
      super.reset();
      setMaxNodes(-1);
      evictionAlgorithmClassName = FIFOAlgorithm.class.getName();
   }

   @Override
   public FIFOAlgorithmConfig clone() throws CloneNotSupportedException
   {
      return (FIFOAlgorithmConfig) super.clone();
   }
}