package org.jboss.cache.factories.context;

import org.jboss.cache.InvocationContext;
import org.jboss.cache.transaction.TransactionContext;

import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import javax.transaction.Transaction;

/**
 * This is the factory responsible for creating {@link org.jboss.cache.InvocationContext}s and {@link org.jboss.cache.transaction.TransactionContext}s
 * for requests, based on the configuration used.
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
public interface ContextFactory
{
   /**
    * @return a new invocation context
    */
   InvocationContext createInvocationContext();

   /**
    * @param tx JTA transaction to associate the new context with
    * @return a new transaction context
    * @throws javax.transaction.RollbackException
    *          in the event of an invalid transaaction
    * @throws javax.transaction.SystemException
    *          in the event of an invalid transaction
    */
   TransactionContext createTransactionContext(Transaction tx) throws SystemException, RollbackException;
}
