/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.cache.transaction;


import org.jboss.cache.commands.WriteCommand;

import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import javax.transaction.Transaction;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

/**
 * Information associated with a {@link GlobalTransaction} about the transaction state.
 * <p/>
 * A TransactionContext maintains:
 * <ul>
 * <li>Handle to the local Transaction</li>
 * <li>List of {@link org.jboss.cache.commands.WriteCommand}s that make up this transaction</li>
 * <li>List of locks acquired</li>
 * <li>Any transaction-scope options</li>
 * </ul>
 *
 * @author <a href="mailto:bela@jboss.org">Bela Ban</a>
 * @author Manik Surtani
 * @version $Revision: 6462 $
 * @deprecated will be removed along with optimistic and pessimistic locking.
 */
@Deprecated
public class PessimisticTransactionContext extends AbstractTransactionContext
{
   private List<WriteCommand> allModifications;

   public PessimisticTransactionContext(Transaction tx) throws SystemException, RollbackException
   {
      super(tx);
   }

   @Override
   public void addLocalModification(WriteCommand command)
   {
      if (command == null) return;
      super.addLocalModification(command);
      if (allModifications == null) allModifications = new LinkedList<WriteCommand>();
      allModifications.add(command);
   }

   @Override
   public void addModification(WriteCommand command)
   {
      if (command == null) return;
      super.addModification(command);
      if (allModifications == null) allModifications = new LinkedList<WriteCommand>();
      allModifications.add(command);
   }

   public List<WriteCommand> getAllModifications()
   {
      if (allModifications == null) return Collections.emptyList();
      return allModifications;
   }

   @Override
   public void reset()
   {
      super.reset();
      allModifications = null;
   }
}
