/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.cache.buddyreplication;

import org.jboss.cache.Cache;
import org.jboss.cache.DefaultCacheFactory;
import org.jboss.cache.CacheSPI;
import org.jboss.cache.config.Configuration;
import org.jboss.cache.config.Option;
import org.jboss.cache.config.parsing.XmlConfigurationParser;
import org.jboss.cache.util.TestingUtil;
import org.testng.annotations.Test;

/**
 * @author Mircea.Markus@jboss.com
 * @since 3.0
 */
@Test(groups = "functional")
public class MvccBuddyReplicationTest
{
   private static final String FILE = "configs/mvcc-repl-sync-br.xml";

   public void testSimpleFailure()
   {
      Cache<String, String> cache1 = null, cache2 = null;
      try
      {
         cache1 = createCache();
         TestingUtil.sleepThread(1000);
         cache2 = createCache();

         cache1.put("/test", "key", "value");
         cache1.stop();

         Option option = cache2.getInvocationContext().getOptionOverrides();
         option.setForceDataGravitation(true);
         assert cache2.get("/test", "key").equals("value");
      }
      finally
      {
         TestingUtil.killCaches(cache1, cache2);

      }
   }

   private Cache<String, String> createCache()
   {
      Configuration fileConfig = new XmlConfigurationParser().parseFile(FILE);
      DefaultCacheFactory<String, String> dcf = new DefaultCacheFactory<String, String>();
      return dcf.createCache(fileConfig);
   }

   public void testSimple() throws Exception
   {
      Configuration fileConfig = new XmlConfigurationParser().parseFile(FILE);
      fileConfig.setCacheMode(Configuration.CacheMode.LOCAL);
      DefaultCacheFactory<String, String> dcf = new DefaultCacheFactory<String, String>();
      CacheSPI cache = (CacheSPI) dcf.createCache(fileConfig);
      cache.getTransactionManager().begin();
      cache.put("/a/b/c","key","value");
      cache.put("/a/b/c","key1","value");
      cache.put("/a/b/c","key2","value");
      cache.put("/a/b/c","key2","value");
      cache.put("/a/b/c","key3","value");
      cache.put("/a/b/c","key4","value");
      cache.put("/a/b/c","key5","value");
      cache.getTransactionManager().commit();
      cache.stop();
   }
}
